@@ -81,11 +81,11 @@ from lack.nodes import (
 )
 from lack.output import color_diff, diff, dump_to_file, err, ipynb_diff, out
 from lack.parsing import InvalidInput  # noqa F401
-from lack.parsing import lib2to3_parse, parse_ast, stringify_ast
+from lack.parsing import llib2to3_parse, parse_ast, stringify_ast
 from lack.report import Changed, NothingChanged, Report
 from lack.trans import iter_fexpr_spans
-from lib2to3.pgen2 import token
-from lib2to3.pytree import Leaf, Node
+from llib2to3.pgen2 import token
+from llib2to3.pytree import Leaf, Node
 
 COMPILED = Path(__file__).suffix in (".pyd", ".so")
 
@@ -1097,7 +1097,7 @@ def format_str(src_contents: str, *, mode: Mode) -> str:
 
 
 def _format_str_once(src_contents: str, *, mode: Mode) -> str:
-    src_node = lib2to3_parse(src_contents.lstrip(), mode.target_versions)
+    src_node = llib2to3_parse(src_contents.lstrip(), mode.target_versions)
     dst_blocks: List[LinesBlock] = []
     if mode.target_versions:
         versions = mode.target_versions
