@@ -72,8 +72,8 @@ from lack.trans import (
     Transformer,
     hug_power_op,
 )
-from lib2to3.pgen2 import token
-from lib2to3.pytree import Leaf, Node
+from llib2to3.pgen2 import token
+from llib2to3.pytree import Leaf, Node
 
 # types
 LeafID = int
@@ -174,7 +174,7 @@ class LineGenerator(Visitor[Line]):
 
     def visit_INDENT(self, node: Leaf) -> Iterator[Line]:
         """Increase indentation level, maybe yield a line."""
-        # In lib2to3 INDENT never holds comments.
+        # In llib2to3 INDENT never holds comments.
         yield from self.line(+1)
         yield from self.visit_default(node)
 
