@@ -34,8 +34,8 @@ from lack.nodes import (
     whitespace,
 )
 from lack.strings import str_width
-from lib2to3.pgen2 import token
-from lib2to3.pytree import Leaf, Node
+from llib2to3.pgen2 import token
+from llib2to3.pytree import Leaf, Node
 
 # types
 T = TypeVar("T")
