@@ -54,8 +54,8 @@ from lack.strings import (
     normalize_string_quotes,
     str_width,
 )
-from lib2to3.pgen2 import token
-from lib2to3.pytree import Leaf, Node
+from llib2to3.pgen2 import token
+from llib2to3.pytree import Leaf, Node
 
 
 class CannotTransform(Exception):
